#ifndef MEYE_CONTROL_H
#define MEYE_CONTROL_H

#include "aserial.h"

enum { MEYE_R, MEYE_L };
enum { MEYE_V, MEYE_H };

typedef struct {
	char vert_id[3];	// servo motor id for communicating with Arduino
	int vert_cur;		// current angle
	int vert_pin;		// GPIO pin
	int vert_mid;		// middle position for the servo (degrees)
	int max_up;			// position for the servor to look up (degrees)  
	int max_down;		// position for the servo to look down (degrees)
	int sign_ud;		// multiplier to go from down to up (i.e. if u > d, sign_du = -1)
	char horiz_id[3];	// servo motor id for communicating with Arduino
	int horiz_cur;		// current angle
	int horiz_pin;		// GPIO pin
	int horiz_mid;		// middle position for the servo (degrees)
	int max_right;		// position for the servo to look left (degrees)
	int max_left;		// position for the servor to look right (degrees)  
} meye_t;

typedef struct {
	aserial_t *as;
	meye_t e[2];		// left is 0=MEYE_R, right is 1=MEYE_L
} meyec_t;

meyec_t *meyec_new(void);
void meyec_destroy(meyec_t *ec);
int meyec_move_eye_angle(meyec_t *ec, int meye, int orient, int angle);
int meyec_look_straight_ahead(meyec_t *ec);
#ifndef __QNXNTO__
void meyec_calc_eye_angles(meyec_t *ec, double *RHa, double *RVa, double *LHa, double *LVa, double Ha, double Va, double rld);
#endif
int meyec_move_eyes_to_loc(meyec_t *ec, double Ha, double Va, double rld);
double meyec_get_eye_spacing_half(void);

#endif
